# Table of Contents

- [sap-cloud-alm-integration-for-managing-projects](<./sap-cloud-alm-integration-for-managing-projects.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [SAP Cloud ALM Integration For Managing Projects](<./SAP-Cloud-ALM-Integration-For-Managing-Projects.md>)
  - [Overview](<./SAP-Cloud-ALM-Integration-For-Managing-Projects/Overview.md>)
  - [Benefits of SAP Cloud ALM Integration For Managing Projects](<./SAP-Cloud-ALM-Integration-For-Managing-Projects/Benefits-of-SAP-Cloud-ALM-Integration-For-Managing-Projects.md>)
  - [Detailed Guides](<./SAP-Cloud-ALM-Integration-For-Managing-Projects/Detailed-Guides.md>)
